<!--


  ** DO NOT EDIT THIS FILE
  **
  ** 1) Make all changes to `README.yaml`
  ** 2) Run`make readme` to rebuild this file.
  **
  ** (We maintain HUNDREDS of open source projects. This is how we maintain our sanity.)
  **


  -->

{{ defineDatasource "config" .Env.README_YAML | regexp.Replace ".*" "" }} {{ defineDatasource "includes" .Env.README_INCLUDES | regexp.Replace ".*" "" }}

{{ if has (ds "config") "badges" }}{{- range $badge := (ds "config").badges -}}{{ printf " [![%s](%s)](%s)" $badge.name $badge.image $badge.url }}{{ end }}{{ end }}

# {{(ds "config").name}}{{ if gt (len (ds "config").name) 34 }}{{ print "\n\n" }}{{ end }}

{{ if has (ds "config") "logo" }} ![{{(ds "config").name}}]({{ (ds "config").logo }}) {{- end -}}

{{ if has (ds "config") "description" }} {{(ds "config").description }} {{ end }}

{{ if has (ds "config") "screenshots" }}

## Screenshots

{{ range $screenshot := (ds "config").screenshots }}
{{ printf "![%s](%s)\n*%s*" $screenshot.name $screenshot.url $screenshot.description }}
{{ end }}{{ end }}

{{ if has (ds "config") "features" }}
## Features
{{ range $feature := (ds "config").features }}{{printf "- %s\n" $feature}}{{ end }}
{{ end }}

{{ if has (ds "config") "introduction" }}

## Introduction

{{ (ds "config").introduction -}} {{ end }}


{{ if has (ds "config") "todo" }}

## TODO

{{ range $todo := (ds "config").todo }}
{{ printf "* [%s](%s)" $todo.name $todo.url }}
{{ end }}
{{ end }}

{{ if has (ds "config") "requirements" }}

## Requirements

{{ (ds "config").requirements -}} {{ end }}


{{ if has (ds "config") "installation" }}
## Installation
{{ range $file := (datasource "config").installation -}}
{{ (include "includes" $file) }}
{{- end }}
{{- end }}

{{ if has (ds "config") "usage" }}

## Usage

{{ (ds "config").usage -}} {{ end }}


{{ if has (ds "config") "quickstart" -}}

## Quick Start

{{ (ds "config").quickstart -}} {{ end }}

{{ if has (ds "config") "examples" }}

## Examples

{{ range $file := (datasource "config").examples -}}
{{ (include "includes" $file) }}
{{- end }}
{{ end }}

{{ if has (ds "config") "include" }} {{ range $file := (datasource "config").include -}} {{ (include "includes" $file) }} {{- end }} {{- end }}

{{ if has (ds "config") "related" }}

## Related Projects

Check out these related projects.
{{ range $related := (ds "config").related }}
{{ printf "* [%s](%s) - %s" $related.name $related.url $related.description }}
{{ end }}

{{ end}}

{{ if has (ds "config") "references" }}

## References

For additional context, refer to some of these links.
{{ range $reference := (ds "config").references }}
{{ printf "* [%s](%s) - %s" $reference.name $reference.url $reference.description }}
{{ end }}
{{ end}}

## Help

**Got a question?**

File a GitHub [issue]({{ printf "https://github.com/%s/issues" (ds "config").github_repo}}).

## Contributing

### Bug Reports & Feature Requests

Please use the [issue tracker]({{ printf "https://github.com/%s/issues" (ds "config").github_repo}}) to report any bugs or file feature requests.

### Development

In general, PRs are welcome. We follow the typical "fork-and-pull" Git workflow.

1.  **Fork** the repo on GitHub
2.  **Clone** the project to your own machine
3.  **Commit** changes to your own branch
4.  **Push** your work back up to your fork
5.  Submit a **Pull Request** so that we can review your changes

**NOTE:** Be sure to rebase the latest changes from "upstream" before making a pull request!

## Module Versioning

This Module follows the principles of [Semantic Versioning (SemVer)](https://semver.org/).

Using the given version number of `MAJOR.MINOR.PATCH`, we apply the following constructs:

1. Use the `MAJOR` version for incompatible changes.
1. Use the `MINOR` version when adding functionality in a backwards compatible manner.
1. Use the `PATCH` version when introducing backwards compatible bug fixes.

### Backwards compatibility in `0.0.z` and `0.y.z` version

- In the context of initial development, backwards compatibility in versions `0.0.z` is **not guaranteed** when `z` is
  increased. (Initial development)
- In the context of pre-release, backwards compatibility in versions `0.y.z` is **not guaranteed** when `y` is
  increased. (Pre-release)


{{ if has (ds "config") "copyrights" }}

## Copyrights

{{ range $copyright := (ds "config").copyrights -}} {{ printf "Copyright © %s-%d [%s](%s)\n" $copyright.year time.Now.Year $copyright.name $copyright.url }} {{ end }}

{{ else }}

## Copyright

Copyright © 2018-{{ time.Now.Year }} [Hadenlabs](https://hadenlabs.com)
{{ end}}


## Trademarks

All other trademarks referenced herein are the property of their respective owners.

{{ if has (datasource "config") "contributors" }}

### :star: Contributors

| {{ range $contributor := (ds "config").contributors }}{{ printf " [![%s][%s_avatar]][%s_homepage]<br/>[%s][%s_homepage] |" $contributor.name $contributor.github $contributor.github $contributor.name $contributor.github}}{{ end }}
|{{- range $contributor := (ds "config").contributors -}}---|{{ end }}

{{ range $contributor := (ds "config").contributors -}}
{{- if has $contributor "homepage" }}
{{ printf "  [%s_homepage]: %s" $contributor.github $contributor.homepage }}
{{ else -}}
{{ printf "  [%s_homepage]: https://github.com/%s" $contributor.github $contributor.github }}
{{ end -}}
{{ if has $contributor "avatar" }}
{{ printf "  [%s_avatar]: %s" $contributor.github $contributor.avatar }}
{{ else -}}
{{ printf "  [%s_avatar]: https://github.com/%s.png?size=150" $contributor.github $contributor.github }}
{{- end }}
{{ end }}

{{ end }}


{{ if has (ds "config") "license" }}

## License

The code and styles are licensed under the {{(ds "config").license }} license [See project license.](LICENSE).

{{ end }}

## Don't forget to 🌟 Star 🌟 the repo if you like {{(ds "config").name}}

[Your feedback is appreciated]({{ printf "https://github.com/%s/issues" (ds "config").github_repo}})
